@@ -1,7 +1,7 @@
 #! /bin/bash -e
-# $Id: check_include_def.sh 3757 2015-11-30 12:03:07Z bradbell $
+# $Id: check_include_def.sh 3826 2016-07-17 15:25:25Z bradbell $
 # -----------------------------------------------------------------------------
-# CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
+# CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-16 Bradley M. Bell
 #
 # CppAD is distributed under multiple licenses. This distribution is under
 # the terms of the
@@ -15,31 +15,37 @@ then
 	echo "bin/check_include_def.sh: must be executed from its parent directory"
 	exit 1
 fi
-# -----------------------------------------------------------------------------
+# ---------------------------------------------------------------------------
 echo "Differences between include file names and ifndef at top directives."
 echo "Also make sure same ifndef not used by two different files."
 echo "-------------------------------------------------------------------"
-list=`bin/list_files.sh | sed -n -e '/\.hpp$/p'`
-#
-grep '^# *ifndef *CPPAD_[0-9a-zA-Z_]*_HPP$' $list \
-	| sed -e 's|.*# *ifndef *CPPAD_\([0-9a-zA-Z_]*\)_HPP$|\1.HPP|' \
-	| tr [a-zA-Z] [A-Za-z] \
-	| sort \
-	> bin/check_include_def.1.$$
-#
-echo "$list" | sed -e 's|\([^ ]*\)/||g' | sort -u > bin/check_include_def.2.$$
-#
-if diff bin/check_include_def.1.$$ bin/check_include_def.2.$$
-then
-	different="no"
-else
-	different="yes"
-fi
-rm bin/check_include_def.1.$$
-rm bin/check_include_def.2.$$
+list=`bin/ls_files.sh | sed -n -e '/^cppad\/deprecated\//d' -e '/\.hpp$/p'`
+different='no'
+for file_name in $list
+do
+	dir=`echo $file_name | sed -e 's|/[^/]*$||'`
+	name=`echo $file_name | sed -e 's|^.*/||'`
+	first_dir=`echo $dir | sed -e 's|/.*||'`
+	#
+	macro_name=`sed -n -e '/^# *ifndef *CPPAD_[0-9A-Z_]*_HPP$/p' $file_name | \
+		sed -e 's|^# *ifndef *||'`
+	check=`echo $file_name | tr [a-zA-Z/.] [A-Za-z__]`
+	#
+	if [ "$first_dir" != 'cppad' ]
+	then
+		check="CPPAD_$check"
+	fi
+	#
+	if [ "$macro_name" != "$check" ]
+	then
+		echo " file_name=$file_name"
+		echo "macro_name=$macro_name"
+		different='yes'
+	fi
+done
 #
 echo "-------------------------------------------------------------------"
-if [ $different = "yes" ]
+if [ $different = 'yes' ]
 then
 	echo "Error: nothing should be between the two dashed lines above"
 	exit 1
