@@ -1,10 +1,10 @@
 #! /bin/bash -e
-# $Id: run_doxygen.sh 2722 2013-01-06 16:52:46Z bradbell $
+# $Id: run_doxygen.sh 3853 2016-12-14 14:40:11Z bradbell $
 # -----------------------------------------------------------------------------
-# CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-13 Bradley M. Bell
+# CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-16 Bradley M. Bell
 #
 # CppAD is distributed under multiple licenses. This distribution is under
-# the terms of the 
+# the terms of the
 #                     GNU General Public License Version 3.
 #
 # A copy of this license is included in the COPYING file of this distribution.
@@ -16,10 +16,11 @@ then
 	exit 1
 fi
 echo_eval() {
-     echo $* 
+     echo $*
      eval $*
 }
 # -----------------------------------------------------------------------------
+# run doxygen
 version=`bin/version.sh get`
 error_file='doxygen.err'
 output_directory='doxydoc'
@@ -35,9 +36,33 @@ echo_eval bin/doxyfile.sh $version $error_file $output_directory
 #
 echo 'doxygen doxyfile > doxygen.log'
 doxygen doxyfile       > doxygen.log
+# -----------------------------------------------------------------------------
+# check for warnings and errors
 #
-echo_eval cat doxygen.err
-echo_eval bin/check_doxygen.sh
-#
-echo 'OK: bin/run_doxygen.sh'
-exit 0
+doxygen_version=`doxygen --version  |
+	sed -e 's|\.|*100+|' -e 's|\.|*10+|' -e 's|\..*||'`
+let doxygen_version=$doxygen_version
+if (( $doxygen_version <= 155 ))
+then
+	doxygen_version=`doxygen --version`
+	echo "doxygen version $doxygen_version is <= 1.5.6"
+	echo "Hence it is to old to check for warnings or errors."
+	exit 0
+fi
+if (( $doxygen_version == 163 ))
+then
+	doxygen_version=`doxygen --version`
+	echo "doxygen version $doxygen_version is == 1.6.3"
+	echo "Hence it has a problem with warnings about missing # defines;"
+	echo "see http://comments.gmane.org/gmane.text.doxygen.general/8594"
+	exit 0
+fi
+list=`head doxygen.err`
+if [ "$list" == "" ]
+then
+	echo 'run_doxygen.sh OK'
+	exit 0
+fi
+echo 'bin/run_doxygen.sh: Doxygen errors or warnings; see doxygen.err'
+echo 'run_doxygen.sh: Error'
+exit 1
