@@ -1,7 +1,7 @@
 #! /bin/bash -e
-# $Id: search.sh 3768 2015-12-28 18:58:35Z bradbell $
+# $Id: search.sh 3781 2016-01-18 16:16:22Z bradbell $
 # -----------------------------------------------------------------------------
-# CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
+# CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-16 Bradley M. Bell
 #
 # CppAD is distributed under multiple licenses. This distribution is under
 # the terms of the
@@ -23,7 +23,7 @@ then
 fi
 pattern="$1"
 # -----------------------------------------------------------------------------
-list=`bin/list_files.sh | sed \
+list=`bin/ls_files.sh | sed \
 	-e '/^configure$/d' \
 	-e '/^makefile.in$/d' \
 	-e '/\/makefile.in$/d' \
