@@ -1,9 +1,8 @@
-// $Id$
 # ifndef CPPAD_CORE_DEFINE_HPP
 # define CPPAD_CORE_DEFINE_HPP
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-16 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-17 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the
@@ -18,21 +17,6 @@ Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
 Define processor symbols and macros that are used by CppAD.
 */
 
-// ----------------------------------------------------------------------------
-/*!
-\def CPPAD_OP_CODE_TYPE
-Is the type used to store enum OpCode values. If not the same as OpCode, then
-<code>sizeof(CPPAD_OP_CODE_TYPE) <= sizeof( enum OpCode )</code>
-to conserve memory.
-This type must support \c std::numeric_limits,
-the \c <= operator,
-and conversion to \c size_t.
-Make sure that the type chosen returns true for is_pod<CPPAD_OP_CODE_TYPE>
-in pod_vector.hpp.
-*/
-# define CPPAD_OP_CODE_TYPE unsigned char
-
-
 // ----------------------------------------------------------------------------
 /*!
 \def CPPAD_INLINE_FRIEND_TEMPLATE_FUNCTION
