@@ -1,9 +1,8 @@
-// $Id$
 # ifndef CPPAD_CORE_DRIVERS_HPP
 # define CPPAD_CORE_DRIVERS_HPP
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-16 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-17 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the
@@ -13,36 +12,11 @@ A copy of this license is included in the COPYING file of this distribution.
 Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
 -------------------------------------------------------------------------- */
 
-/*
-$begin Drivers$$
-$spell
-$$
-
-
-$section First and Second Derivatives: Easy Drivers$$
-$mindex forward reverse$$
-
-
-$childtable%
-	cppad/core/jacobian.hpp%
-	cppad/core/for_one.hpp%
-	cppad/core/rev_one.hpp%
-	cppad/core/hessian.hpp%
-	cppad/core/for_two.hpp%
-	cppad/core/rev_two.hpp%
-	cppad/core/sparse_jacobian.hpp%
-	cppad/core/sparse_hessian.hpp
-%$$
-
-$end
-*/
 # include <cppad/core/jacobian.hpp>
+# include <cppad/core/hessian.hpp>
 # include <cppad/core/for_one.hpp>
 # include <cppad/core/rev_one.hpp>
-# include <cppad/core/hessian.hpp>
 # include <cppad/core/for_two.hpp>
 # include <cppad/core/rev_two.hpp>
-# include <cppad/core/sparse_jacobian.hpp>
-# include <cppad/core/sparse_hessian.hpp>
 
 # endif
