@@ -1,9 +1,8 @@
-// $Id$
 # ifndef CPPAD_CORE_FUN_EVAL_HPP
 # define CPPAD_CORE_FUN_EVAL_HPP
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-16 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-17 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the
@@ -13,23 +12,6 @@ A copy of this license is included in the COPYING file of this distribution.
 Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
 -------------------------------------------------------------------------- */
 
-/*
-$begin FunEval$$
-$spell
-$$
-
-
-$section Evaluate ADFun Functions, Derivatives, and Sparsity Patterns$$
-
-$childtable%
-	omh/forward/forward.omh%
-	omh/reverse/reverse.omh%
-	cppad/core/sparse.hpp
-%$$
-
-$end
-*/
-
 # include <cppad/core/forward.hpp>
 # include <cppad/core/reverse.hpp>
 # include <cppad/core/sparse.hpp>
