@@ -1,9 +1,8 @@
-// $Id$
 # ifndef CPPAD_CORE_SPARSE_HPP
 # define CPPAD_CORE_SPARSE_HPP
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-16 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-17 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the
@@ -13,29 +12,27 @@ A copy of this license is included in the COPYING file of this distribution.
 Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
 -------------------------------------------------------------------------- */
 
-/*
-$begin Sparse$$
-$spell
-$$
-
-
-$section Calculating Sparsity Patterns$$
-
-$childtable%
-	cppad/core/for_sparse_jac.hpp%
-	cppad/core/rev_sparse_jac.hpp%
-	example/dependency.cpp%
-	cppad/core/rev_sparse_hes.hpp%
-	cppad/core/for_sparse_hes.hpp%
-	example/bool_sparsity.cpp
-%$$
-
-$end
-*/
-
+//
+# include <cppad/core/for_jac_sparsity.hpp>
+# include <cppad/core/rev_jac_sparsity.hpp>
+//
+# include <cppad/core/for_hes_sparsity.hpp>
+# include <cppad/core/rev_hes_sparsity.hpp>
+//
 # include <cppad/core/for_sparse_jac.hpp>
 # include <cppad/core/rev_sparse_jac.hpp>
-# include <cppad/core/rev_sparse_hes.hpp>
+//
 # include <cppad/core/for_sparse_hes.hpp>
+# include <cppad/core/rev_sparse_hes.hpp>
+//
+# include <cppad/core/sparse_jac.hpp>
+# include <cppad/core/sparse_hes.hpp>
+//
+# include <cppad/core/sparse_jacobian.hpp>
+# include <cppad/core/sparse_hessian.hpp>
+//
+# include <cppad/core/subgraph_sparsity.hpp>
+# include <cppad/core/subgraph_reverse.hpp>
+# include <cppad/core/subgraph_jac_rev.hpp>
 
 # endif
