@@ -1,8 +1,7 @@
-// $Id: cppad_eigen.hpp 3804 2016-03-20 15:08:46Z bradbell $
 # ifndef CPPAD_EXAMPLE_CPPAD_EIGEN_HPP
 # define CPPAD_EXAMPLE_CPPAD_EIGEN_HPP
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-16 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-17 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the
@@ -20,7 +19,6 @@ $spell
 	inline
 	neg
 	eps
-	plugin
 	atan
 	Num
 	acos
@@ -46,28 +44,30 @@ $head Syntax$$
 $codei%# include <cppad/example/cppad_eigen.hpp>%$$
 $children%
 	cppad/example/eigen_plugin.hpp%
-	example/eigen_array.cpp%
-	example/eigen_det.cpp
+	example/general/eigen_array.cpp%
+	example/general/eigen_det.cpp
 %$$
 
 $head Purpose$$
-Enables the use of the
-$href%http://eigen.tuxfamily.org%eigen%$$
-linear algebra package with the type $icode%AD<%Base%>%$$.
+Enables the use of the $cref/eigen/eigen_prefix/$$
+linear algebra package with the type $icode%AD<%Base%>%$$; see
+$href%
+	https://eigen.tuxfamily.org/dox/TopicCustomizing_CustomScalar.html%
+	custom scalar types
+%$$.
 
 $head Example$$
 The files $cref eigen_array.cpp$$ and $cref eigen_det.cpp$$
 contain an example and test of this include file.
-It returns true if it succeeds and false otherwise.
+They return true if they succeed and false otherwise.
 
 $head Include Files$$
 The file $code cppad_eigen.hpp$$ includes both
 $code <cppad/cppad.hpp>$$ and $code <Eigen/Core>$$.
-In addition,
-The file $cref eigen_plugin.hpp$$
-is used to define $code value_type$$
-in the Eigen matrix class definition so its vectors are
-$cref/simple vectors/SimpleVector/$$.
+The file $cref eigen_plugin.hpp$$ defines $code value_type$$
+in the Eigen matrix class so its vectors are
+$cref/simple vectors/SimpleVector/$$
+(not necessary for eigen-3.3.3 and later).
 $srccode%cpp% */
 # define EIGEN_MATRIXBASE_PLUGIN <cppad/example/eigen_plugin.hpp>
 # include <Eigen/Core>
@@ -83,6 +83,8 @@ namespace Eigen {
 		typedef CppAD::AD<Base>   Real;
 		// type for AD<Base> operations that result in non-integer values
 		typedef CppAD::AD<Base>   NonInteger;
+		//  type to use for numeric literals such as "2" or "0.5".
+		typedef CppAD::AD<Base>   Literal;
 		// type for nested value inside an AD<Base> expression tree
 		typedef CppAD::AD<Base>   Nested;
 
@@ -121,6 +123,9 @@ namespace Eigen {
 		static CppAD::AD<Base> highest(void)
 		{	return CppAD::numeric_limits< CppAD::AD<Base> >::max(); }
 
+		// number of decimal digits that can be represented without change.
+		static int digits10(void)
+		{	return CppAD::numeric_limits< CppAD::AD<Base> >::digits10; }
 	};
 }
 /* %$$
@@ -142,26 +147,6 @@ namespace CppAD {
 		{	return x * x; }
 }
 
-namespace Eigen {
-	namespace internal {
-
-		template<class Base>
-		struct significant_decimals_default_impl< CppAD::AD<Base>, false>
-		{	typedef CppAD::AD<Base> Scalar;
-
-			typedef typename NumTraits<Scalar>::Real RealScalar;
-			static inline int run()
-			{	Scalar neg_log_eps = - log(
-					NumTraits<RealScalar>::epsilon()
-				);
-				int ceil_neg_log_eps = Integer( neg_log_eps );
-				if( Scalar(ceil_neg_log_eps) < neg_log_eps )
-					ceil_neg_log_eps++;
-				return ceil_neg_log_eps;
-			}
-		};
-	}
-}
 /* %$$
 $end
 */
