@@ -1,10 +1,9 @@
-// $Id$
 # ifndef CPPAD_LOCAL_ACOSH_OP_HPP
 # define CPPAD_LOCAL_ACOSH_OP_HPP
 # if CPPAD_USE_CPLUSPLUS_2011
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-16 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-17 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the
@@ -36,7 +35,7 @@ The auxillary result is
 The value of y, and its derivatives, are computed along with the value
 and derivatives of z.
 
-\copydetails forward_unary2_op
+\copydetails CppAD::local::forward_unary2_op
 */
 template <class Base>
 inline void forward_acosh_op(
@@ -62,24 +61,24 @@ inline void forward_acosh_op(
 	Base uj;
 	if( p == 0 )
 	{	z[0] = acosh( x[0] );
-		uj   = x[0] * x[0] - Base(1);
+		uj   = x[0] * x[0] - Base(1.0);
 		b[0] = sqrt( uj );
 		p++;
 	}
 	for(size_t j = p; j <= q; j++)
-	{	uj = Base(0);
+	{	uj = Base(0.0);
 		for(k = 0; k <= j; k++)
 			uj += x[k] * x[j-k];
-		b[j] = Base(0);
-		z[j] = Base(0);
+		b[j] = Base(0.0);
+		z[j] = Base(0.0);
 		for(k = 1; k < j; k++)
-		{	b[j] -= Base(k) * b[k] * b[j-k];
-			z[j] -= Base(k) * z[k] * b[j-k];
+		{	b[j] -= Base(double(k)) * b[k] * b[j-k];
+			z[j] -= Base(double(k)) * z[k] * b[j-k];
 		}
-		b[j] /= Base(j);
-		z[j] /= Base(j);
+		b[j] /= Base(double(j));
+		z[j] /= Base(double(j));
 		//
-		b[j] += uj / Base(2);
+		b[j] += uj / Base(2.0);
 		z[j] += x[j];
 		//
 		b[j] /= b[0];
@@ -100,7 +99,7 @@ The auxillary result is
 The value of y, and its derivatives, are computed along with the value
 and derivatives of z.
 
-\copydetails forward_unary2_op_dir
+\copydetails CppAD::local::forward_unary2_op_dir
 */
 template <class Base>
 inline void forward_acosh_op_dir(
@@ -129,14 +128,14 @@ inline void forward_acosh_op_dir(
 	{	Base uq = 2.0 * x[m + ell] * x[0];
 		for(k = 1; k < q; k++)
 			uq += x[(k-1)*r+1+ell] * x[(q-k-1)*r+1+ell];
-		b[m+ell] = Base(0);
-		z[m+ell] = Base(0);
+		b[m+ell] = Base(0.0);
+		z[m+ell] = Base(0.0);
 		for(k = 1; k < q; k++)
-		{	b[m+ell] += Base(k) * b[(k-1)*r+1+ell] * b[(q-k-1)*r+1+ell];
-			z[m+ell] += Base(k) * z[(k-1)*r+1+ell] * b[(q-k-1)*r+1+ell];
+		{	b[m+ell] += Base(double(k)) * b[(k-1)*r+1+ell] * b[(q-k-1)*r+1+ell];
+			z[m+ell] += Base(double(k)) * z[(k-1)*r+1+ell] * b[(q-k-1)*r+1+ell];
 		}
-		b[m+ell] =  ( uq / Base(2) - b[m+ell] / Base(q) ) / b[0];
-		z[m+ell] = ( x[m+ell]     - z[m+ell] / Base(q) ) / b[0];
+		b[m+ell] =  ( uq / Base(2.0) - b[m+ell] / Base(double(q)) ) / b[0];
+		z[m+ell] = ( x[m+ell]     - z[m+ell] / Base(double(q)) ) / b[0];
 	}
 }
 
@@ -153,7 +152,7 @@ The auxillary result is
 \endverbatim
 The value of y is computed along with the value of z.
 
-\copydetails forward_unary2_op_0
+\copydetails CppAD::local::forward_unary2_op_0
 */
 template <class Base>
 inline void forward_acosh_op_0(
@@ -173,7 +172,7 @@ inline void forward_acosh_op_0(
 	Base* b = z      -       cap_order; // called y in documentation
 
 	z[0] = acosh( x[0] );
-	b[0] = sqrt( x[0] * x[0] - Base(1) );
+	b[0] = sqrt( x[0] * x[0] - Base(1.0) );
 }
 /*!
 Compute reverse mode partial derivatives for result of op = AcoshOp.
@@ -188,7 +187,7 @@ The auxillary result is
 \endverbatim
 The value of y is computed along with the value of z.
 
-\copydetails reverse_unary2_op
+\copydetails CppAD::local::reverse_unary2_op
 */
 
 template <class Base>
@@ -219,7 +218,7 @@ inline void reverse_acosh_op(
 	const Base* b  = z  - cap_order; // called y in documentation
 	Base* pb       = pz - nc_partial;
 
-	Base inv_b0 = Base(1) / b[0];
+	Base inv_b0 = Base(1.0) / b[0];
 
 	// number of indices to access
 	size_t j = d;
@@ -242,17 +241,17 @@ inline void reverse_acosh_op(
 		px[j] += pz[j] + azmul(pb[j], x[0]);
 
 		// further scale partial w.r.t. z[j] by 1 / j
-		pz[j] /= Base(j);
+		pz[j] /= Base(double(j));
 
 		for(k = 1; k < j; k++)
 		{	// update partials w.r.t b^(j-k)
-			pb[j-k] -= Base(k) * azmul(pz[j], z[k]) + azmul(pb[j], b[k]);
+			pb[j-k] -= Base(double(k)) * azmul(pz[j], z[k]) + azmul(pb[j], b[k]);
 
 			// update partials w.r.t. x^k
 			px[k]   += azmul(pb[j], x[j-k]);
 
 			// update partials w.r.t. z^k
-			pz[k]   -= Base(k) * azmul(pz[j], b[j-k]);
+			pz[k]   -= Base(double(k)) * azmul(pz[j], b[j-k]);
 		}
 		--j;
 	}
