@@ -1,10 +1,9 @@
-// $Id$
 # ifndef CPPAD_LOCAL_ATANH_OP_HPP
 # define CPPAD_LOCAL_ATANH_OP_HPP
 # if CPPAD_USE_CPLUSPLUS_2011
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-16 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-17 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the
@@ -36,7 +35,7 @@ The auxillary result is
 The value of y, and its derivatives, are computed along with the value
 and derivatives of z.
 
-\copydetails forward_unary2_op
+\copydetails CppAD::local::forward_unary2_op
 */
 template <class Base>
 inline void forward_atanh_op(
@@ -61,18 +60,18 @@ inline void forward_atanh_op(
 	size_t k;
 	if( p == 0 )
 	{	z[0] = atanh( x[0] );
-		b[0] = Base(1) - x[0] * x[0];
+		b[0] = Base(1.0) - x[0] * x[0];
 		p++;
 	}
 	for(size_t j = p; j <= q; j++)
 	{
-		b[j] = - Base(2) * x[0] * x[j];
-		z[j] = Base(0);
+		b[j] = - Base(2.0) * x[0] * x[j];
+		z[j] = Base(0.0);
 		for(k = 1; k < j; k++)
 		{	b[j] -= x[k] * x[j-k];
-			z[j] -= Base(k) * z[k] * b[j-k];
+			z[j] -= Base(double(k)) * z[k] * b[j-k];
 		}
-		z[j] /= Base(j);
+		z[j] /= Base(double(j));
 		z[j] += x[j];
 		z[j] /= b[0];
 	}
@@ -92,7 +91,7 @@ The auxillary result is
 The value of y, and its derivatives, are computed along with the value
 and derivatives of z.
 
-\copydetails forward_unary2_op_dir
+\copydetails CppAD::local::forward_unary2_op_dir
 */
 template <class Base>
 inline void forward_atanh_op_dir(
@@ -117,13 +116,13 @@ inline void forward_atanh_op_dir(
 
 	size_t m = (q-1) * r + 1;
 	for(size_t ell = 0; ell < r; ell++)
-	{	b[m+ell] = - Base(2) * x[m+ell] * x[0];
-		z[m+ell] = Base(q) * x[m+ell];
+	{	b[m+ell] = - Base(2.0) * x[m+ell] * x[0];
+		z[m+ell] = Base(double(q)) * x[m+ell];
 		for(size_t k = 1; k < q; k++)
 		{	b[m+ell] -= x[(k-1)*r+1+ell] * x[(q-k-1)*r+1+ell];
-			z[m+ell] -= Base(k) * z[(k-1)*r+1+ell] * b[(q-k-1)*r+1+ell];
+			z[m+ell] -= Base(double(k)) * z[(k-1)*r+1+ell] * b[(q-k-1)*r+1+ell];
 		}
-		z[m+ell] /= ( Base(q) * b[0] );
+		z[m+ell] /= ( Base(double(q)) * b[0] );
 	}
 }
 
@@ -140,7 +139,7 @@ The auxillary result is
 \endverbatim
 The value of y is computed along with the value of z.
 
-\copydetails forward_unary2_op_0
+\copydetails CppAD::local::forward_unary2_op_0
 */
 template <class Base>
 inline void forward_atanh_op_0(
@@ -160,7 +159,7 @@ inline void forward_atanh_op_0(
 	Base* b = z      -       cap_order; // called y in documentation
 
 	z[0] = atanh( x[0] );
-	b[0] = Base(1) - x[0] * x[0];
+	b[0] = Base(1.0) - x[0] * x[0];
 }
 /*!
 Reverse mode partial derivatives for result of op = AtanhOp.
@@ -175,7 +174,7 @@ The auxillary result is
 \endverbatim
 The value of y is computed along with the value of z.
 
-\copydetails reverse_unary2_op
+\copydetails CppAD::local::reverse_unary2_op
 */
 
 template <class Base>
@@ -206,7 +205,7 @@ inline void reverse_atanh_op(
 	const Base* b  = z  - cap_order; // called y in documentation
 	Base* pb       = pz - nc_partial;
 
-	Base inv_b0 = Base(1) / b[0];
+	Base inv_b0 = Base(1.0) / b[0];
 
 	// number of indices to access
 	size_t j = d;
@@ -214,23 +213,23 @@ inline void reverse_atanh_op(
 	while(j)
 	{	// scale partials w.r.t z[j] and b[j]
 		pz[j]  = azmul(pz[j], inv_b0);
-		pb[j] *= Base(2);
+		pb[j] *= Base(2.0);
 
 		pb[0] -= azmul(pz[j], z[j]);
 		px[j] += pz[j] - azmul(pb[j], x[0]);
 		px[0] -= azmul(pb[j], x[j]);
 
 		// more scaling of partials w.r.t z[j]
-		pz[j] /= Base(j);
+		pz[j] /= Base(double(j));
 
 		for(k = 1; k < j; k++)
-		{	pb[j-k] -= Base(k) * azmul(pz[j], z[k]);
-			pz[k]   -= Base(k) * azmul(pz[j], b[j-k]);
+		{	pb[j-k] -= Base(double(k)) * azmul(pz[j], z[k]);
+			pz[k]   -= Base(double(k)) * azmul(pz[j], b[j-k]);
 			px[k]   -= azmul(pb[j], x[j-k]);
 		}
 		--j;
 	}
-	px[0] += azmul(pz[0], inv_b0) - Base(2) * azmul(pb[0], x[0]);
+	px[0] += azmul(pz[0], inv_b0) - Base(2.0) * azmul(pb[0], x[0]);
 }
 
 } } // END_CPPAD_LOCAL_NAMESPACE
