@@ -1,8 +1,8 @@
-// $Id: cond_op.hpp 3757 2015-11-30 12:03:07Z bradbell $
-# ifndef CPPAD_COND_OP_HPP
-# define CPPAD_COND_OP_HPP
+// $Id: cond_op.hpp 3845 2016-11-19 01:50:47Z bradbell $
+# ifndef CPPAD_LOCAL_COND_OP_HPP
+# define CPPAD_LOCAL_COND_OP_HPP
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-16 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the
@@ -12,7 +12,7 @@ A copy of this license is included in the COPYING file of this distribution.
 Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
 -------------------------------------------------------------------------- */
 
-namespace CppAD { // BEGIN_CPPAD_NAMESPACE
+namespace CppAD { namespace local { // BEGIN_CPPAD_LOCAL_NAMESPACE
 /*!
 \file cond_op.hpp
 Forward, reverse, and sparse operations for conditional expressions.
@@ -119,7 +119,7 @@ where Rel is one of the following: Lt, Le, Eq, Ge, Gt.
 
 \tparam Vector_set
 is the type used for vectors of sets. It can be either
-\c sparse_pack, \c sparse_set, or \c sparse_list.
+sparse_pack or sparse_list.
 
 \param i_z
 is the AD variable index corresponding to the variable z.
@@ -892,7 +892,7 @@ where Rel is one of the following: Lt, Le, Eq, Ge, Gt.
 
 \tparam Vector_set
 is the type used for vectors of sets. It can be either
-\c sparse_pack, \c sparse_set, or \c sparse_list.
+sparse_pack or sparse_list.
 
 \param i_z
 is the AD variable index corresponding to the variable z.
@@ -1031,7 +1031,7 @@ where Rel is one of the following: Lt, Le, Eq, Ge, Gt.
 
 \tparam Vector_set
 is the type used for vectors of sets. It can be either
-\c sparse_pack, \c sparse_set, or \c sparse_list.
+sparse_pack or sparse_list.
 
 \param i_z
 is the AD variable index corresponding to the variable z.
@@ -1172,7 +1172,7 @@ where Rel is one of the following: Lt, Le, Eq, Ge, Gt.
 
 \tparam Vector_set
 is the type used for vectors of sets. It can be either
-\c sparse_pack, \c sparse_set, or \c sparse_list.
+sparse_pack or sparse_list.
 
 \param i_z
 is the AD variable index corresponding to the variable z.
@@ -1309,5 +1309,5 @@ inline void reverse_sparse_hessian_cond_op(
 	return;
 }
 
-} // END_CPPAD_NAMESPACE
+} } // END_CPPAD_LOCAL_NAMESPACE
 # endif
