@@ -1,9 +1,8 @@
-// $Id: cosh_op.hpp 3845 2016-11-19 01:50:47Z bradbell $
 # ifndef CPPAD_LOCAL_COSH_OP_HPP
 # define CPPAD_LOCAL_COSH_OP_HPP
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-16 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-17 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the
@@ -35,7 +34,7 @@ The auxillary result is
 The value of y, and its derivatives, are computed along with the value
 and derivatives of z.
 
-\copydetails forward_unary2_op
+\copydetails CppAD::local::forward_unary2_op
 */
 template <class Base>
 inline void forward_cosh_op(
@@ -68,14 +67,14 @@ inline void forward_cosh_op(
 	}
 	for(size_t j = p; j <= q; j++)
 	{
-		s[j] = Base(0);
-		c[j] = Base(0);
+		s[j] = Base(0.0);
+		c[j] = Base(0.0);
 		for(k = 1; k <= j; k++)
-		{	s[j] += Base(k) * x[k] * c[j-k];
-			c[j] += Base(k) * x[k] * s[j-k];
+		{	s[j] += Base(double(k)) * x[k] * c[j-k];
+			c[j] += Base(double(k)) * x[k] * s[j-k];
 		}
-		s[j] /= Base(j);
-		c[j] /= Base(j);
+		s[j] /= Base(double(j));
+		c[j] /= Base(double(j));
 	}
 }
 /*!
@@ -92,7 +91,7 @@ The auxillary result is
 The value of y, and its derivatives, are computed along with the value
 and derivatives of z.
 
-\copydetails forward_unary2_op_dir
+\copydetails CppAD::local::forward_unary2_op_dir
 */
 template <class Base>
 inline void forward_cosh_op_dir(
@@ -121,14 +120,14 @@ inline void forward_cosh_op_dir(
 	// (except that there is a sign difference for the hyperbolic case).
 	size_t m = (q-1) * r + 1;
 	for(size_t ell = 0; ell < r; ell++)
-	{	s[m+ell] = Base(q) * x[m + ell] * c[0];
-		c[m+ell] = Base(q) * x[m + ell] * s[0];
+	{	s[m+ell] = Base(double(q)) * x[m + ell] * c[0];
+		c[m+ell] = Base(double(q)) * x[m + ell] * s[0];
 		for(size_t k = 1; k < q; k++)
-		{	s[m+ell] += Base(k) * x[(k-1)*r+1+ell] * c[(q-k-1)*r+1+ell];
-			c[m+ell] += Base(k) * x[(k-1)*r+1+ell] * s[(q-k-1)*r+1+ell];
+		{	s[m+ell] += Base(double(k)) * x[(k-1)*r+1+ell] * c[(q-k-1)*r+1+ell];
+			c[m+ell] += Base(double(k)) * x[(k-1)*r+1+ell] * s[(q-k-1)*r+1+ell];
 		}
-		s[m+ell] /= Base(q);
-		c[m+ell] /= Base(q);
+		s[m+ell] /= Base(double(q));
+		c[m+ell] /= Base(double(q));
 	}
 }
 
@@ -145,7 +144,7 @@ The auxillary result is
 \endverbatim
 The value of y is computed along with the value of z.
 
-\copydetails forward_unary2_op_0
+\copydetails CppAD::local::forward_unary2_op_0
 */
 template <class Base>
 inline void forward_cosh_op_0(
@@ -180,7 +179,7 @@ The auxillary result is
 \endverbatim
 The value of y is computed along with the value of z.
 
-\copydetails reverse_unary2_op
+\copydetails CppAD::local::reverse_unary2_op
 */
 
 template <class Base>
@@ -218,15 +217,15 @@ inline void reverse_cosh_op(
 	size_t k;
 	while(j)
 	{
-		ps[j]   /= Base(j);
-		pc[j]   /= Base(j);
+		ps[j]   /= Base(double(j));
+		pc[j]   /= Base(double(j));
 		for(k = 1; k <= j; k++)
 		{
-			px[k]   += Base(k) * azmul(ps[j], c[j-k]);
-			px[k]   += Base(k) * azmul(pc[j], s[j-k]);
+			px[k]   += Base(double(k)) * azmul(ps[j], c[j-k]);
+			px[k]   += Base(double(k)) * azmul(pc[j], s[j-k]);
 
-			ps[j-k] += Base(k) * azmul(pc[j], x[k]);
-			pc[j-k] += Base(k) * azmul(ps[j], x[k]);
+			ps[j-k] += Base(double(k)) * azmul(pc[j], x[k]);
+			pc[j-k] += Base(double(k)) * azmul(ps[j], x[k]);
 
 		}
 		--j;
