@@ -1,8 +1,7 @@
-// $Id: for_jac_sweep.hpp 3853 2016-12-14 14:40:11Z bradbell $
 # ifndef CPPAD_LOCAL_FOR_JAC_SWEEP_HPP
 # define CPPAD_LOCAL_FOR_JAC_SWEEP_HPP
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-16 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-17 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the
@@ -34,9 +33,7 @@ Given the sparsity pattern for the independent variables,
 ForJacSweep computes the sparsity pattern for all the other variables.
 
 \tparam Base
-base type for the operator; i.e., this operation sequence was recorded
-using AD< \a Base > and computations by this routine are done using type
-\a Base.
+this operation sequence was recorded using AD<Base>.
 
 \tparam Vector_set
 is the type used for vectors of sets. It can be either
@@ -65,10 +62,6 @@ is a recording of the operations corresponding to a function
 \f]
 where \f$ n \f$ is the number of independent variables
 and \f$ m \f$ is the number of dependent variables.
-The object \a play is effectly constant.
-It is not declared const because while playing back the tape
-the object \a play holds information about the current location
-with in the tape and this changes during playback.
 
 \param var_sparsity
 \b Input: For j = 1 , ... , \a n,
@@ -86,12 +79,12 @@ corresponds to the set with index i in \a var_sparsity.
 */
 
 template <class Base, class Vector_set>
-void ForJacSweep(
-	bool                  dependency   ,
-	size_t                n            ,
-	size_t                numvar       ,
-	local::player<Base>*         play         ,
-	Vector_set&           var_sparsity )
+void for_jac_sweep(
+	const local::player<Base>* play,
+	bool                       dependency        ,
+	size_t                     n                 ,
+	size_t                     numvar            ,
+	Vector_set&                var_sparsity )
 {
 	OpCode           op;
 	size_t         i_op;
@@ -118,10 +111,10 @@ void ForJacSweep(
 	size_t num_vecad_ind   = play->num_vec_ind_rec();
 	size_t num_vecad_vec   = play->num_vecad_vec_rec();
 	Vector_set  vecad_sparsity;
-	vecad_sparsity.resize(num_vecad_vec, limit);
 	pod_vector<size_t> vecad_ind;
 	if( num_vecad_vec > 0 )
 	{	size_t length;
+		vecad_sparsity.resize(num_vecad_vec, limit);
 		vecad_ind.extend(num_vecad_ind);
 		j             = 0;
 		for(i = 0; i < num_vecad_vec; i++)
@@ -138,58 +131,42 @@ void ForJacSweep(
 	}
 
 	// --------------------------------------------------------------
+	// user's atomic op calculator
+	atomic_base<Base>* user_atom = CPPAD_NULL;
+	//
 	// work space used by UserOp.
+	vector<Base>       user_x;   // value of parameter arguments to function
+	vector<size_t>     user_ix;  // variable index (on tape) for each argument
+	vector<size_t>     user_iy;  // variable index (on tape) for each result
 	//
-	vector<Base>       user_x;   // parameters in x as integers
-	//
-	typedef std::set<size_t> size_set;
-	size_set::iterator set_itr;  // iterator for a standard set
-	size_set::iterator set_end;  // end of iterator sequence
-	vector< size_set > set_r;    // set sparsity pattern for the argument x
-	vector< size_set > set_s;    // set sparisty pattern for the result y
-	//
-	vector<bool>       bool_r;   // bool sparsity pattern for the argument x
-	vector<bool>       bool_s;   // bool sparisty pattern for the result y
-	//
-	vectorBool         pack_r;   // pack sparsity pattern for the argument x
-	vectorBool         pack_s;   // pack sparisty pattern for the result y
-	//
-	const size_t user_q = limit; // maximum element plus one
-	//
-	// information defined by forward_user
+	// information set by forward_user (initialization to avoid warnings)
 	size_t user_old=0, user_m=0, user_n=0, user_i=0, user_j=0;
-	enum_user_state user_state = start_user; // proper initialization
-	//
-	atomic_base<Base>* user_atom = CPPAD_NULL; // user's atomic op calculator
-	bool               user_pack = false;      // sparsity pattern type is pack
-	bool               user_bool = false;      // sparsity pattern type is bool
-	bool               user_set  = false;      // sparsity pattern type is set
-	bool               user_ok   = false;      // atomic op return value
+	// information set by forward_user (necessary initialization)
+	enum_user_state user_state = start_user;
+	// --------------------------------------------------------------
 	//
 	// pointer to the beginning of the parameter vector
 	// (used by user atomic functions)
 	const Base* parameter = CPPAD_NULL;
 	if( num_par > 0 )
 		parameter = play->GetPar();
-	// --------------------------------------------------------------
 
 # if CPPAD_FOR_JAC_SWEEP_TRACE
+	vector<size_t>    user_usrrp; // parameter index for UsrrpOp operators
 	std::cout << std::endl;
 	CppAD::vectorBool z_value(limit);
 # endif
 
 	// skip the BeginOp at the beginning of the recording
-	play->forward_start(op, arg, i_op, i_var);
+	i_op = 0;
+	play->get_op_info(i_op, op, arg, i_var);
 	CPPAD_ASSERT_UNKNOWN( op == BeginOp );
 	bool more_operators = true;
 	while(more_operators)
 	{	bool flag; // temporary for use in switch cases.
 
 		// this op
-		play->forward_next(op, arg, i_op, i_var);
-		CPPAD_ASSERT_UNKNOWN( (i_op > n)  | (op == InvOp) );
-		CPPAD_ASSERT_UNKNOWN( (i_op <= n) | (op != InvOp) );
-		CPPAD_ASSERT_ARG_BEFORE_RESULT(op, arg, i_var);
+		play->get_op_info(++i_op, op, arg, i_var);
 
 		// rest of information depends on the case
 		switch( op )
@@ -279,21 +256,13 @@ void ForJacSweep(
 			// -------------------------------------------------
 
 			case CSkipOp:
-			// CSipOp has a variable number of arguments and
-			// forward_next thinks it has no arguments.
-			// we must inform forward_next of this special case.
-			play->forward_cskip(op, arg, i_op, i_var);
 			break;
 			// -------------------------------------------------
 
 			case CSumOp:
-			// CSumOp has a variable number of arguments and
-			// forward_next thinks it has no arguments.
-			// we must inform forward_next of this special case.
 			forward_sparse_jacobian_csum_op(
 				i_var, arg, var_sparsity
 			);
-			play->forward_csum(op, arg, i_op, i_var);
 			break;
 			// -------------------------------------------------
 
@@ -635,179 +604,96 @@ void ForJacSweep(
 			// -------------------------------------------------
 
 			case UserOp:
-			// start or end an atomic operation sequence
-			flag = user_state == start_user;
-			user_atom = play->forward_user(op, user_state,
-				user_old, user_m, user_n, user_i, user_j
+			// start or end an atomic function call
+			CPPAD_ASSERT_UNKNOWN(
+				user_state == start_user || user_state == end_user
 			);
+			flag = user_state == start_user;
+			user_atom = play->get_user_info(op, arg, user_old, user_m, user_n);
 			if( flag )
-			{	user_x.resize( user_n );
+			{	user_state = arg_user;
+				user_i     = 0;
+				user_j     = 0;
 				//
-				user_pack  = user_atom->sparsity() ==
-							atomic_base<Base>::pack_sparsity_enum;
-				user_bool  = user_atom->sparsity() ==
-							atomic_base<Base>::bool_sparsity_enum;
-				user_set   = user_atom->sparsity() ==
-							atomic_base<Base>::set_sparsity_enum;
-				CPPAD_ASSERT_UNKNOWN( user_pack || user_bool || user_set );
-				if( user_pack )
-				{	pack_r.resize( user_n * user_q );
-					pack_s.resize( user_m * user_q );
-					for(i = 0; i < user_n; i++)
-						for(j = 0; j < user_q; j++)
-							pack_r[ i * user_q + j] = false;
-				}
-				if( user_bool )
-				{	bool_r.resize( user_n * user_q );
-					bool_s.resize( user_m * user_q );
-					for(i = 0; i < user_n; i++)
-						for(j = 0; j < user_q; j++)
-							bool_r[ i * user_q + j] = false;
-				}
-				if( user_set)
-				{	set_r.resize(user_n);
-					set_s.resize(user_m);
-					for(i = 0; i < user_n; i++)
-						set_r[i].clear();
-				}
+				user_x.resize( user_n );
+				user_ix.resize( user_n );
+				user_iy.resize( user_m );
+# if CPPAD_FOR_JAC_SWEEP_TRACE
+				user_usrrp.resize( user_m );
+# endif
 			}
 			else
-			{
-# ifndef NDEBUG
-				if( ! user_ok )
-				{	std::string msg =
-						user_atom->afun_name()
-						+ ": atomic_base.for_sparse_jac: returned false\n";
-					if( user_pack )
-						msg += "sparsity = pack_sparsity_enum";
-					if( user_bool )
-						msg += "sparsity = bool_sparsity_enum";
-					if( user_set )
-						msg += "sparsity = set_sparsity_enum";
-					CPPAD_ASSERT_KNOWN(false, msg.c_str() );
-				}
-# endif
+			{	user_state = start_user;
+				//
+				user_atom->set_old(user_old);
+				user_atom->for_sparse_jac(
+					user_x, user_ix, user_iy, var_sparsity
+				);
 			}
 			break;
 
 			case UsrapOp:
-			// parameter argument in an atomic operation sequence
-			user_x[user_j] = parameter[arg[0]];
+			// parameter argument for a user atomic function
+			CPPAD_ASSERT_UNKNOWN( NumArg(op) == 1 );
+			CPPAD_ASSERT_UNKNOWN( user_state == arg_user );
+			CPPAD_ASSERT_UNKNOWN( user_i == 0 );
+			CPPAD_ASSERT_UNKNOWN( user_j < user_n );
+			CPPAD_ASSERT_UNKNOWN( size_t( arg[0] ) < num_par );
 			//
-			// set row user_j to empty sparsity pattern
-			play->forward_user(op, user_state,
-				user_old, user_m, user_n, user_i, user_j
-			);
+			user_x[user_j]  = parameter[arg[0]];
+			user_ix[user_j] = 0; // special variable used for parameters
+			//
+			++user_j;
 			if( user_j == user_n )
-			{	// call users function for this operation
-				user_atom->set_old(user_old);
-				if( user_pack )
-				{	user_ok = user_atom->for_sparse_jac(
-						user_q, pack_r, pack_s, user_x
-					);
-					if( ! user_ok ) user_ok = user_atom->for_sparse_jac(
-						user_q, pack_r, pack_s
-					);
-				}
-				if( user_bool )
-				{	user_ok = user_atom->for_sparse_jac(
-						user_q, bool_r, bool_s, user_x
-					);
-					if( ! user_ok ) user_ok = user_atom->for_sparse_jac(
-						user_q, bool_r, bool_s
-					);
-				}
-				if( user_set )
-				{	user_ok = user_atom->for_sparse_jac(
-						user_q, set_r, set_s, user_x
-					);
-					if( ! user_ok ) user_ok = user_atom->for_sparse_jac(
-						user_q, set_r, set_s
-					);
-				}
-			}
+				user_state = ret_user;
 			break;
 
 			case UsravOp:
-			// variable argument in an atomic operation sequence
-			// variable as integers
-			user_x[user_j] = CppAD::numeric_limits<Base>::quiet_NaN();
-			// set row user_j to sparsity pattern for variable arg[0]
-			{	typename Vector_set::const_iterator itr(var_sparsity, arg[0]);
-				i = *itr;
-				while( i < user_q )
-				{	if( user_pack )
-						pack_r[user_j * user_q + i] = true;
-					if( user_bool )
-						bool_r[user_j * user_q + i] = true;
-					if( user_set )
-						set_r[user_j].insert(i);
-					i = *(++itr);
-				}
-			}
-			play->forward_user(op, user_state,
-				user_old, user_m, user_n, user_i, user_j
-			);
+			// variable argument for a user atomic function
+			CPPAD_ASSERT_UNKNOWN( NumArg(op) == 1 );
+			CPPAD_ASSERT_UNKNOWN( user_state == arg_user );
+			CPPAD_ASSERT_UNKNOWN( user_i == 0 );
+			CPPAD_ASSERT_UNKNOWN( user_j < user_n );
+			//
+			// argument variables not avaiable during sparsity calculations
+			user_x[user_j]  = CppAD::numeric_limits<Base>::quiet_NaN();
+			user_ix[user_j] = arg[0]; // variable for this argument
+			//
+			++user_j;
 			if( user_j == user_n )
-			{	// call users function for this operation
-				user_atom->set_old(user_old);
-				if( user_pack )
-				{	user_ok = user_atom->for_sparse_jac(
-						user_q, pack_r, pack_s, user_x
-					);
-					if( ! user_ok ) user_ok = user_atom->for_sparse_jac(
-						user_q, pack_r, pack_s
-					);
-				}
-				if( user_bool )
-				{	user_ok = user_atom->for_sparse_jac(
-						user_q, bool_r, bool_s, user_x
-					);
-					if( ! user_ok ) user_ok = user_atom->for_sparse_jac(
-						user_q, bool_r, bool_s
-					);
-				}
-				if( user_set )
-				{	user_ok = user_atom->for_sparse_jac(
-						user_q, set_r, set_s, user_x
-					);
-					if( ! user_ok ) user_ok = user_atom->for_sparse_jac(
-						user_q, set_r, set_s
-					);
-				}
-			}
+				user_state = ret_user;
 			break;
 
 			case UsrrpOp:
-			// parameter result in an atomic operation sequence
-			play->forward_user(op, user_state,
-				user_old, user_m, user_n, user_i, user_j
-			);
+			// parameter result for a user atomic function
+			CPPAD_ASSERT_NARG_NRES(op, 1, 0);
+			CPPAD_ASSERT_UNKNOWN( user_state == ret_user );
+			CPPAD_ASSERT_UNKNOWN( user_i < user_m );
+			CPPAD_ASSERT_UNKNOWN( user_j == user_n );
+			CPPAD_ASSERT_UNKNOWN( size_t( arg[0] ) < num_par );
+			//
+			user_iy[user_i] = 0; // special variable user for parameters
+# if CPPAD_FOR_JAC_SWEEP_TRACE
+			// remember argument for delayed tracing
+			user_usrrp[user_i] = arg[0];
+# endif
+			++user_i;
+			if( user_i == user_m )
+				user_state = end_user;
 			break;
 
 			case UsrrvOp:
-			// variable result in an atomic operation sequence
-			// It might be faster if we add set union to var_sparsity
-			// where one of the sets is not in var_sparsity
-			if( user_pack )
-			{	for(j = 0; j < user_q; j++)
-					if( pack_s[ user_i * user_q + j ] )
-						var_sparsity.add_element(i_var, j);
-			}
-			if( user_bool )
-			{	for(j = 0; j < user_q; j++)
-					if( bool_s[ user_i * user_q + j ] )
-						var_sparsity.add_element(i_var, j);
-			}
-			if( user_set )
-			{	set_itr = set_s[user_i].begin();
-				set_end = set_s[user_i].end();
-				while( set_itr != set_end )
-					var_sparsity.add_element(i_var, *set_itr++);
-			}
-			play->forward_user(op, user_state,
-				user_old, user_m, user_n, user_i, user_j
-			);
+			// variable result for a user atomic function
+			CPPAD_ASSERT_NARG_NRES(op, 0, 1);
+			CPPAD_ASSERT_UNKNOWN( user_state == ret_user );
+			CPPAD_ASSERT_UNKNOWN( user_i < user_m );
+			CPPAD_ASSERT_UNKNOWN( user_j == user_n );
+			//
+			user_iy[user_i] = i_var; // variable index for this result
+			//
+			++user_i;
+			if( user_i == user_m )
+				user_state = end_user;
 			break;
 			// -------------------------------------------------
 
@@ -839,12 +725,48 @@ void ForJacSweep(
 			CPPAD_ASSERT_UNKNOWN(0);
 		}
 # if CPPAD_FOR_JAC_SWEEP_TRACE
-		const addr_t*   arg_tmp = arg;
-		if( op == CSumOp )
-			arg_tmp = arg - arg[-1] - 4;
-		if( op == CSkipOp )
-			arg_tmp = arg - arg[-1] - 7;
-		//
+		if( op == UserOp && user_state == start_user )
+		{	// print operators that have been delayed
+			CPPAD_ASSERT_UNKNOWN( user_m == user_iy.size() );
+			CPPAD_ASSERT_UNKNOWN( i_op > user_m );
+			CPPAD_ASSERT_NARG_NRES(UsrrpOp, 1, 0);
+			CPPAD_ASSERT_NARG_NRES(UsrrvOp, 0, 1);
+			addr_t arg_tmp[1];
+			for(i = 0; i < user_m; i++)
+			{	size_t j_var = user_iy[i];
+				// value for this variable
+				for(j = 0; j < limit; j++)
+					z_value[j] = false;
+				typename Vector_set::const_iterator itr(var_sparsity, j_var);
+				j = *itr;
+				while( j < limit )
+				{	z_value[j] = true;
+					j = *(++itr);
+				}
+				OpCode op_tmp = UsrrvOp;
+				if( j_var == 0 )
+				{	op_tmp     = UsrrpOp;
+					arg_tmp[0] = user_usrrp[i];
+				}
+				// j_var is zero when there is no result.
+				printOp(
+					std::cout,
+					play,
+					i_op - user_m + i,
+					j_var,
+					op_tmp,
+					arg_tmp
+				);
+				if( j_var > 0 ) printOpResult(
+					std::cout,
+					1,
+					&z_value,
+					0,
+					(CppAD::vectorBool *) CPPAD_NULL
+				);
+				std::cout << std::endl;
+			}
+		}
 		// value for this variable
 		for(j = 0; j < limit; j++)
 			z_value[j] = false;
@@ -854,28 +776,32 @@ void ForJacSweep(
 		{	z_value[j] = true;
 			j = *(++itr);
 		}
-		printOp(
-			std::cout,
-			play,
-			i_op,
-			i_var,
-			op,
-			arg_tmp
-		);
-		if( NumRes(op) > 0 ) printOpResult(
-			std::cout,
-			1,
-			&z_value,
-			0,
-			(CppAD::vectorBool *) CPPAD_NULL
-		);
-		std::cout << std::endl;
+		// must delay print for these cases till after atomic user call
+		bool delay_print = op == UsrrpOp;
+		delay_print     |= op == UsrrvOp;
+		if( ! delay_print )
+		{	 printOp(
+				std::cout,
+				play,
+				i_op,
+				i_var,
+				op,
+				arg
+			);
+			if( NumRes(op) > 0 && (! delay_print) ) printOpResult(
+				std::cout,
+				1,
+				&z_value,
+				0,
+				(CppAD::vectorBool *) CPPAD_NULL
+			);
+			std::cout << std::endl;
+		}
 	}
 	std::cout << std::endl;
 # else
 	}
 # endif
-	CPPAD_ASSERT_UNKNOWN( i_var + 1 == play->num_var_rec() );
 
 	return;
 }
