@@ -1,9 +1,8 @@
-// $Id: pod_vector.hpp 3845 2016-11-19 01:50:47Z bradbell $
 # ifndef CPPAD_LOCAL_POD_VECTOR_HPP
 # define CPPAD_LOCAL_POD_VECTOR_HPP
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-16 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-17 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the
@@ -19,49 +18,13 @@ Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
 # include <algorithm>
 # include <cppad/utility/thread_alloc.hpp>
 # include <cppad/core/cppad_assert.hpp>
-# include <cppad/local/op_code.hpp>
+# include <cppad/local/is_pod.hpp>
 
 namespace CppAD { namespace local { // BEGIN_CPPAD_LOCAL_NAMESPACE
 /*!
 \file pod_vector.hpp
 File used to define pod_vector class
 */
-
-/*
-A list of which Types pod_vector<Type> consideres to be plain old data
-*/
-/// default value is false
-template <class Type> inline bool is_pod(void)           { return false; }
-/// system pod types so far:
-template <> inline bool is_pod<bool>(void)               { return true; }
-template <> inline bool is_pod<float>(void)              { return true; }
-template <> inline bool is_pod<double>(void)             { return true; }
-# if CPPAD_CSTDINT_HAS_8_TO_64
-template <> inline bool is_pod<int8_t>(void)             { return true;  }
-template <> inline bool is_pod<int16_t>(void)            { return true;  }
-template <> inline bool is_pod<int32_t>(void)            { return true;  }
-template <> inline bool is_pod<int64_t>(void)            { return true;  }
-//
-template <> inline bool is_pod<uint8_t>(void)            { return true;  }
-template <> inline bool is_pod<uint16_t>(void)           { return true;  }
-template <> inline bool is_pod<uint32_t>(void)           { return true;  }
-template <> inline bool is_pod<uint64_t>(void)           { return true;  }
-# else // CPPAD_CSTDINT_HAS_8_TO_64
-template <> inline bool is_pod<char>(void)               { return true; }
-template <> inline bool is_pod<short int>(void)          { return true; }
-template <> inline bool is_pod<int>(void)                { return true; }
-//
-template <> inline bool is_pod<unsigned char>(void)      { return true; }
-template <> inline bool is_pod<unsigned short int>(void) { return true; }
-template <> inline bool is_pod<unsigned int>(void)       { return true; }
-# if CPPAD_SIZE_T_NOT_UNSIGNED_INT
-template <> inline bool is_pod<size_t>(void)             { return true; }
-# endif
-# endif // CPPAD_CSTDINT_HAS_8_TO_64
-
-/// CppAD pod types so far:
-template <> inline bool is_pod<OpCode>(void)             { return true; }
-
 // ---------------------------------------------------------------------------
 /*!
 A vector class with Type element that does not use element constructors
@@ -70,28 +33,31 @@ or destructors when Type is Plain Old Data (pod).
 template <class Type>
 class pod_vector {
 private:
-	/// maximum number of elements that should ever be in this vector
-	size_t max_length_;
 	/// number of elements currently in this vector
 	size_t length_;
+	//
 	/// maximum number of Type elements current allocation can hold
 	size_t capacity_;
+	//
 	/// pointer to the first type elements
 	/// (not defined and should not be used when capacity_ = 0)
 	Type   *data_;
+	//
 	/// do not use the copy constructor
 	explicit pod_vector(const pod_vector& )
 	{	CPPAD_ASSERT_UNKNOWN(false); }
 public:
-	/// Constructors set capacity, length, and data to zero.
-	///
-	/// \param max_length
-	/// value for maximum number of elements in this vector.
-	inline pod_vector(
-		size_t max_length = std::numeric_limits<size_t>::max()
-	)
-	: max_length_(max_length), length_(0), capacity_(0), data_(CPPAD_NULL)
-	{ }
+	/// default constructor sets capacity_ = length_ = data_ = 0
+	pod_vector(void)
+	: length_(0), capacity_(0), data_(CPPAD_NULL)
+	{	CPPAD_ASSERT_UNKNOWN( is_pod<size_t>() );
+	}
+	/// sizing constructor
+	pod_vector(
+		/// number of elements in this vector
+		size_t n
+	)   : length_(0), capacity_(0), data_(CPPAD_NULL)
+	{	extend(n); }
 	// ----------------------------------------------------------------------
 	/// Destructor: returns allocated memory to \c thread_alloc;
 	/// see \c extend.  If this is not plain old data,
@@ -110,48 +76,46 @@ public:
 	}
 	// ----------------------------------------------------------------------
 	/// current number of elements in this vector.
-	inline size_t size(void) const
+	size_t size(void) const
 	{	return length_; }
+	//
 	/// current capacity (amount of allocated storage) for this vector.
-	inline size_t capacity(void) const
+	size_t capacity(void) const
 	{	return capacity_; }
-	/// current data pointer, no longer valid after any of the following:
+	//
+	/// current data pointer is no longer valid after any of the following:
 	/// extend, erase, operator=, and ~pod_vector.
 	/// Take extreem care when using this function.
-	inline Type* data(void)
+	Type* data(void)
 	{	return data_; }
-	/// const version of \c data pointer
-	inline const Type* data(void) const
+	//
+	/// const version of data pointer (see non-const documentation)
+	const Type* data(void) const
 	{	return data_; }
 	// ----------------------------------------------------------------------
 	/*!
-	Increase the number of elements the end of this vector.
+	Increase the number of elements the end of this vector
+	(existing elements are always preserved).
 
 	\param n
 	is the number of elements to add to end of this vector.
 
 	\return
 	is the number  of elements in the vector before \c extend was extended.
+	This is the index of the first new element added to the vector.
 
 	- If \c Type is plain old data, new elements are not initialized;
 	i.e., their constructor is not called. Otherwise, the constructor
 	is called for each new element.
 
-	- This is the only routine that allocates memory for \c pod_vector.
-	and it uses thread_alloc for this allocation, hence this determines
-	which thread corresponds to this vector (when in parallel mode).
-
-	- If the resulting length of the vector would be more than \c max_length_,
-	and \c NDEBUG is not defined, a CPPAD_ASSERT is generated.
+	- This and resize are the only routine that allocate memory for
+	\c pod_vector. They uses thread_alloc for this allocation, hence this
+	determines which thread corresponds to this vector (when in parallel mode).
 	*/
-	inline size_t extend(size_t n)
+	size_t extend(size_t n)
 	{	size_t old_length   = length_;
 		length_            += n;
-		CPPAD_ASSERT_KNOWN(
-			length_ <= max_length_ ,
-			"pod_vector.hpp: attempt to create to large a vector.\n"
-			"If Type is CPPAD_TYPE_ADDR_TYPE, tape is too long for Type."
-		);
+
 		// check if we can use current memory
 		if( capacity_ >= length_ )
 			return old_length;
@@ -193,6 +157,61 @@ public:
 		return old_length;
 	}
 	// ----------------------------------------------------------------------
+	/*!
+	resize the vector (existing elements preserved when n <= capacity_).
+
+	\param n
+	is the new size for this vector.
+
+	\par
+	if n <= capacity(), no memory is freed or allocated, the capacity
+	is not changed, and existing elements are preserved.
+	If n > capacity(), new memory is allocates and all the
+	data in the vector is lost.
+
+	- If \c Type is plain old data, new elements are not initialized;
+	i.e., their constructor is not called. Otherwise, the constructor
+	is called for each new element.
+
+	- This and extend are the only routine that allocate memory for
+	\c pod_vector. They uses thread_alloc for this allocation, hence this
+	determines which thread corresponds to this vector (when in parallel mode).
+	*/
+	void resize(size_t n)
+	{	length_ = n;
+
+		// check if we must allocate new memory
+		if( capacity_ < length_ )
+		{	void* v_ptr;
+			//
+			// return old memory to available pool
+			if( capacity_ > 0 )
+			{	v_ptr = reinterpret_cast<void*>( data_ );
+				if( ! is_pod<Type>() )
+				{	// call destructor for each old element
+					for(size_t i = 0; i < capacity_; i++)
+						(data_ + i)->~Type();
+				}
+				thread_alloc::return_memory(v_ptr);
+			}
+			//
+			// get new memory and set capacity
+			size_t length_bytes = length_ * sizeof(Type);
+			size_t capacity_bytes;
+			v_ptr     = thread_alloc::get_memory(length_bytes, capacity_bytes);
+			capacity_ = capacity_bytes / sizeof(Type);
+			data_     = reinterpret_cast<Type*>(v_ptr);
+			//
+			CPPAD_ASSERT_UNKNOWN( length_ <= capacity_ );
+			//
+			if( ! is_pod<Type>() )
+			{	// call constructor for each new element
+				for(size_t i = 0; i < capacity_; i++)
+					new(data_ + i) Type();
+			}
+		}
+	}
+	// ----------------------------------------------------------------------
 	/// non-constant element access; i.e., we can change this element value
 	Type& operator[](
 		/// element index, must be less than length
@@ -222,9 +241,9 @@ public:
 	}
 	// ----------------------------------------------------------------------
 	/*!
-	Remove all the elements from this vector and delete its memory.
+	Remove all the elements from this vector and free its memory.
 	*/
-	void free(void)
+	void clear(void)
 	{	if( capacity_ > 0 )
 		{	void* v_ptr = reinterpret_cast<void*>( data_ );
 			if( ! is_pod<Type>() )
@@ -239,10 +258,8 @@ public:
 		capacity_ = 0;
 		length_   = 0;
 	}
+	// -----------------------------------------------------------------------
 	/// vector assignment operator
-	/// If the resulting length of the vector would be more than
-	/// \c max_length_, and \c NDEBUG is not defined,
-	/// a CPPAD_ASSERT is generated.
 	void operator=(
 		/// right hand size of the assingment operation
 		const pod_vector& x
@@ -252,11 +269,6 @@ public:
 		if( x.length_ <= capacity_ )
 		{	// use existing allocation for this vector
 			length_ = x.length_;
-			CPPAD_ASSERT_KNOWN(
-				length_ <= max_length_ ,
-				"pod_vector.hpp: attempt to create to large a vector.\n"
-				"If Type is CPPAD_TYPE_ADDR_TYPE, tape long for Type."
-			);
 		}
 		else
 		{	// free old memory and get new memory of sufficient length
@@ -276,8 +288,11 @@ public:
 		for(i = 0; i < length_; i++)
 		{	data_[i] = x.data_[i]; }
 	}
+	// -----------------------------------------------------------------------
 	/*!
 	Swap all properties of this vector with another.
+	This is useful when moving a vector that grows after it has reached
+	its final size (without copying every element).
 
 	\param other
 	is the other vector that we are swapping this vector with.
@@ -287,6 +302,17 @@ public:
 		std::swap(length_,   other.length_);
 		std::swap(data_,     other.data_);
 	}
+	// ------------------------------------------------------------------------
+	/*!
+	Add an element to theh back of this vector
+
+	\param e
+	is the element we are adding to the back of the vector.
+	*/
+	void push_back(const Type& e)
+	{	size_t i = extend(1);
+		data_[i] = e;
+	}
 };
 
 } } // END_CPPAD_LOCAL_NAMESPACE
