@@ -1,9 +1,9 @@
-// $Id: std_set.hpp 3757 2015-11-30 12:03:07Z bradbell $
-# ifndef CPPAD_STD_SET_HPP
-# define CPPAD_STD_SET_HPP
+// $Id: std_set.hpp 3845 2016-11-19 01:50:47Z bradbell $
+# ifndef CPPAD_LOCAL_STD_SET_HPP
+# define CPPAD_LOCAL_STD_SET_HPP
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-16 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the
@@ -13,12 +13,12 @@ A copy of this license is included in the COPYING file of this distribution.
 Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
 -------------------------------------------------------------------------- */
 
-# include <cppad/local/define.hpp>
+# include <cppad/core/define.hpp>
 
 // needed before one can use CPPAD_ASSERT_FIRST_CALL_NOT_PARALLEL
 # include <cppad/utility/thread_alloc.hpp>
 
-namespace CppAD { // BEGIN_CPPAD_NAMESPACE
+namespace CppAD { namespace local { // BEGIN_CPPAD_LOCAL_NAMESPACE
 /*!
 \file std_set.hpp
 Two constant standard sets (currently used for concept checking).
@@ -49,5 +49,5 @@ const std::set<Scalar>& two_element_std_set(void)
 	return two;
 }
 
-} // END_CPPAD_NAMESPACE
+} } // END_CPPAD_LOCAL_NAMESPACE
 # endif
