@@ -1,9 +1,9 @@
-// $Id: sub_op.hpp 3845 2016-11-19 01:50:47Z bradbell $
+// $Id: sub_op.hpp 3865 2017-01-19 01:57:55Z bradbell $
 # ifndef CPPAD_LOCAL_SUB_OP_HPP
 # define CPPAD_LOCAL_SUB_OP_HPP
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-16 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-17 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the
@@ -31,7 +31,7 @@ In the documentation below,
 this operations is for the case where both x and y are variables
 and the argument \a parameter is not used.
 
-\copydetails forward_binary_op
+\copydetails CppAD::local::forward_binary_op
 */
 
 template <class Base>
@@ -69,7 +69,7 @@ In the documentation below,
 this operations is for the case where both x and y are variables
 and the argument \a parameter is not used.
 
-\copydetails forward_binary_op_dir
+\copydetails CppAD::local::forward_binary_op_dir
 */
 
 template <class Base>
@@ -110,7 +110,7 @@ In the documentation below,
 this operations is for the case where both x and y are variables
 and the argument \a parameter is not used.
 
-\copydetails forward_binary_op_0
+\copydetails CppAD::local::forward_binary_op_0
 */
 
 template <class Base>
@@ -144,7 +144,7 @@ In the documentation below,
 this operations is for the case where both x and y are variables
 and the argument \a parameter is not used.
 
-\copydetails reverse_binary_op
+\copydetails CppAD::local::reverse_binary_op
 */
 
 template <class Base>
@@ -189,7 +189,7 @@ The C++ source code corresponding to this operation is
 In the documentation below,
 this operations is for the case where x is a parameter and y is a variable.
 
-\copydetails forward_binary_op
+\copydetails CppAD::local::forward_binary_op
 */
 
 template <class Base>
@@ -231,7 +231,7 @@ The C++ source code corresponding to this operation is
 In the documentation below,
 this operations is for the case where x is a parameter and y is a variable.
 
-\copydetails forward_binary_op_dir
+\copydetails CppAD::local::forward_binary_op_dir
 */
 
 template <class Base>
@@ -270,7 +270,7 @@ The C++ source code corresponding to this operation is
 In the documentation below,
 this operations is for the case where x is a parameter and y is a variable.
 
-\copydetails forward_binary_op_0
+\copydetails CppAD::local::forward_binary_op_0
 */
 
 template <class Base>
@@ -305,7 +305,7 @@ The C++ source code corresponding to this operation is
 In the documentation below,
 this operations is for the case where x is a parameter and y is a variable.
 
-\copydetails reverse_binary_op
+\copydetails CppAD::local::reverse_binary_op
 */
 
 template <class Base>
@@ -348,7 +348,7 @@ The C++ source code corresponding to this operation is
 In the documentation below,
 this operations is for the case where x is a variable and y is a parameter.
 
-\copydetails forward_binary_op
+\copydetails CppAD::local::forward_binary_op
 */
 
 template <class Base>
@@ -390,7 +390,7 @@ The C++ source code corresponding to this operation is
 In the documentation below,
 this operations is for the case where x is a variable and y is a parameter.
 
-\copydetails forward_binary_op_dir
+\copydetails CppAD::local::forward_binary_op_dir
 */
 
 template <class Base>
@@ -430,7 +430,7 @@ The C++ source code corresponding to this operation is
 In the documentation below,
 this operations is for the case where x is a variable and y is a parameter.
 
-\copydetails forward_binary_op_0
+\copydetails CppAD::local::forward_binary_op_0
 */
 
 template <class Base>
@@ -465,7 +465,7 @@ The C++ source code corresponding to this operation is
 In the documentation below,
 this operations is for the case where x is a variable and y is a parameter.
 
-\copydetails reverse_binary_op
+\copydetails CppAD::local::reverse_binary_op
 */
 
 template <class Base>
