@@ -1,9 +1,8 @@
-// $Id: rosen_34.hpp 3845 2016-11-19 01:50:47Z bradbell $
 # ifndef CPPAD_UTILITY_ROSEN_34_HPP
 # define CPPAD_UTILITY_ROSEN_34_HPP
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-16 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-17 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the
@@ -265,7 +264,7 @@ must not be $cref/parallel/ta_in_parallel/$$ execution mode.
 
 $head Example$$
 $children%
-	example/rosen_34.cpp
+	example/general/rosen_34.cpp
 %$$
 The file
 $cref rosen_34.cpp$$
