@@ -1,9 +1,9 @@
-// $Id: ode_simple.hpp 3757 2015-11-30 12:03:07Z bradbell $
-# ifndef CPPAD_ODE_SIMPLE_HPP
-# define CPPAD_ODE_SIMPLE_HPP
+// $Id: ode_simple.hpp 3804 2016-03-20 15:08:46Z bradbell $
+# ifndef CPPAD_CPPAD_IPOPT_EXAMPLE_ODE_SIMPLE_HPP
+# define CPPAD_CPPAD_IPOPT_EXAMPLE_ODE_SIMPLE_HPP
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-16 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the
@@ -26,7 +26,7 @@ $mindex cppad_ipopt_nlp example source$$
 
 
 $code
-$verbatim%cppad_ipopt/example/ode_simple.hpp%0%// BEGIN C++%// END C++%1%$$
+$srcfile%cppad_ipopt/example/ode_simple.hpp%0%// BEGIN C++%// END C++%1%$$
 $$
 
 $end
