@@ -8,38 +8,51 @@ var list_across0 = [
 var list_up0 = [
 'cppad.xml',
 'adfun.xml',
-'funeval.xml',
-'sparse.xml',
+'sparsity_pattern.xml',
 'dependency.cpp.xml'
 ];
 var list_down3 = [
-'independent.xml',
-'funconstruct.xml',
-'dependent.xml',
-'abort_recording.xml',
-'seq_property.xml',
-'funeval.xml',
-'drivers.xml',
-'funcheck.xml',
-'optimize.xml',
-'check_for_nan.xml'
+'install.xml',
+'introduction.xml',
+'ad.xml',
+'adfun.xml',
+'preprocessor.xml',
+'multi_thread.xml',
+'utility.xml',
+'ipopt_solve.xml',
+'example.xml',
+'speed.xml',
+'appendix.xml'
 ];
 var list_down2 = [
+'record_adfun.xml',
+'drivers.xml',
 'forward.xml',
 'reverse.xml',
-'sparse.xml'
+'sparsity_pattern.xml',
+'sparse_derivative.xml',
+'optimize.xml',
+'abs_normal.xml',
+'funcheck.xml',
+'check_for_nan.xml'
 ];
 var list_down1 = [
+'for_jac_sparsity.xml',
 'forsparsejac.xml',
+'rev_jac_sparsity.xml',
 'revsparsejac.xml',
-'dependency.cpp.xml',
+'rev_hes_sparsity.xml',
 'revsparsehes.xml',
+'for_hes_sparsity.xml',
 'forsparsehes.xml',
-'bool_sparsity.cpp.xml'
+'dependency.cpp.xml',
+'rc_sparsity.cpp.xml',
+'subgraph_sparsity.xml'
 ];
 var list_current0 = [
 'dependency.cpp.xml#Discussion',
-'dependency.cpp.xml#Dependency Pattern'
+'dependency.cpp.xml#Dependency Pattern',
+'dependency.cpp.xml#Computation'
 ];
 function choose_across0(item)
 {	var index          = item.selectedIndex;
