@@ -25,10 +25,9 @@ var list_down3 = [
 'appendix.xml'
 ];
 var list_down2 = [
-'get_started.cpp.xml',
 'exp_2.xml',
 'exp_eps.xml',
-'exp_apx_main.cpp.xml'
+'exp_apx.cpp.xml'
 ];
 var list_down1 = [
 'exp_2.hpp.xml',
