@@ -24,10 +24,12 @@ var list_down2 = [
 'appendix.xml'
 ];
 var list_down1 = [
+'get_started.cpp.xml',
 'general.xml',
 'exampleutility.xml',
 'listallexamples.xml',
-'testvector.xml'
+'testvector.xml',
+'wno_conversion.xml'
 ];
 var list_down0 = [
 'ad_fun.cpp.xml',
