@@ -23,10 +23,9 @@ var list_down1 = [
 'appendix.xml'
 ];
 var list_down0 = [
-'get_started.cpp.xml',
 'exp_2.xml',
 'exp_eps.xml',
-'exp_apx_main.cpp.xml'
+'exp_apx.cpp.xml'
 ];
 var list_current0 = [
 'introduction.xml#Purpose',
