@@ -26,7 +26,7 @@ var list_down2 = [
 'unaryplus.xml',
 'unaryminus.xml',
 'ad_binary.xml',
-'compute_assign.xml'
+'compound_assign.xml'
 ];
 var list_down1 = [
 'add.cpp.xml',
