@@ -8,20 +8,27 @@ var list_across0 = [
 var list_up0 = [
 'cppad.xml',
 'adfun.xml',
-'funeval.xml',
 'reverse.xml',
 'reverse_any.xml',
 'reverse_three.cpp.xml'
 ];
 var list_down3 = [
+'record_adfun.xml',
+'drivers.xml',
 'forward.xml',
 'reverse.xml',
-'sparse.xml'
+'sparsity_pattern.xml',
+'sparse_derivative.xml',
+'optimize.xml',
+'abs_normal.xml',
+'funcheck.xml',
+'check_for_nan.xml'
 ];
 var list_down2 = [
 'reverse_one.xml',
 'reverse_two.xml',
-'reverse_any.xml'
+'reverse_any.xml',
+'subgraph_reverse.xml'
 ];
 var list_down1 = [
 'reverse_three.cpp.xml',
