@@ -8,31 +8,28 @@ var list_across0 = [
 var list_up0 = [
 'cppad.xml',
 'adfun.xml',
-'drivers.xml',
+'sparse_derivative.xml',
 'sparse_hessian.xml',
 'sparse_hessian.cpp.xml'
 ];
 var list_down3 = [
-'independent.xml',
-'funconstruct.xml',
-'dependent.xml',
-'abort_recording.xml',
-'seq_property.xml',
-'funeval.xml',
+'record_adfun.xml',
 'drivers.xml',
-'funcheck.xml',
+'forward.xml',
+'reverse.xml',
+'sparsity_pattern.xml',
+'sparse_derivative.xml',
 'optimize.xml',
+'abs_normal.xml',
+'funcheck.xml',
 'check_for_nan.xml'
 ];
 var list_down2 = [
-'jacobian.xml',
-'forone.xml',
-'revone.xml',
-'hessian.xml',
-'fortwo.xml',
-'revtwo.xml',
+'sparse_jac.xml',
 'sparse_jacobian.xml',
-'sparse_hessian.xml'
+'sparse_hes.xml',
+'sparse_hessian.xml',
+'subgraph_jac_rev.xml'
 ];
 var list_down1 = [
 'sparse_hessian.cpp.xml',
