@@ -8,23 +8,34 @@ var list_across0 = [
 var list_up0 = [
 'cppad.xml',
 'adfun.xml',
-'funeval.xml',
-'sparse.xml',
+'sparsity_pattern.xml',
 'revsparsehes.xml',
 'sparsity_sub.cpp.xml'
 ];
 var list_down3 = [
+'record_adfun.xml',
+'drivers.xml',
 'forward.xml',
 'reverse.xml',
-'sparse.xml'
+'sparsity_pattern.xml',
+'sparse_derivative.xml',
+'optimize.xml',
+'abs_normal.xml',
+'funcheck.xml',
+'check_for_nan.xml'
 ];
 var list_down2 = [
+'for_jac_sparsity.xml',
 'forsparsejac.xml',
+'rev_jac_sparsity.xml',
 'revsparsejac.xml',
-'dependency.cpp.xml',
+'rev_hes_sparsity.xml',
 'revsparsehes.xml',
+'for_hes_sparsity.xml',
 'forsparsehes.xml',
-'bool_sparsity.cpp.xml'
+'dependency.cpp.xml',
+'rc_sparsity.cpp.xml',
+'subgraph_sparsity.xml'
 ];
 var list_down1 = [
 'rev_sparse_hes.cpp.xml',
