@@ -25,13 +25,15 @@ var list_down3 = [
 'appendix.xml'
 ];
 var list_down2 = [
+'get_started.cpp.xml',
 'general.xml',
 'exampleutility.xml',
 'listallexamples.xml',
-'testvector.xml'
+'testvector.xml',
+'wno_conversion.xml'
 ];
 var list_down1 = [
-'example.cpp.xml',
+'general.cpp.xml',
 'speed_example.cpp.xml',
 'lu_vec_ad.cpp.xml'
 ];
