@@ -55,12 +55,15 @@ var list_current0 = [
 'speed_main.xml#seed',
 'speed_main.xml#Global Options',
 'speed_main.xml#Global Options.onetape',
+'speed_main.xml#Global Options.memory',
 'speed_main.xml#Global Options.optimize',
 'speed_main.xml#Global Options.atomic',
-'speed_main.xml#Global Options.memory',
+'speed_main.xml#Global Options.hes2jac',
+'speed_main.xml#Global Options.subgraph',
 'speed_main.xml#Sparsity Options',
 'speed_main.xml#Sparsity Options.boolsparsity',
 'speed_main.xml#Sparsity Options.revsparsity',
+'speed_main.xml#Sparsity Options.subsparsity',
 'speed_main.xml#Sparsity Options.colpack',
 'speed_main.xml#Correctness Results',
 'speed_main.xml#Speed Results',
