@@ -30,6 +30,7 @@ var list_down2 = [
 'speed_test.xml',
 'speedtest.xml',
 'time_test.xml',
+'test_boolofvoid.xml',
 'numerictype.xml',
 'checknumerictype.xml',
 'simplevector.xml',
@@ -49,7 +50,9 @@ var list_down2 = [
 'thread_alloc.xml',
 'index_sort.xml',
 'to_string.xml',
-'set_union.xml'
+'set_union.xml',
+'sparse_rc.xml',
+'sparse_rcv.xml'
 ];
 var list_down1 = [
 'thread_alloc.cpp.xml',
