@@ -29,6 +29,7 @@ var list_down1 = [
 'speed_test.xml',
 'speedtest.xml',
 'time_test.xml',
+'test_boolofvoid.xml',
 'numerictype.xml',
 'checknumerictype.xml',
 'simplevector.xml',
@@ -48,7 +49,9 @@ var list_down1 = [
 'thread_alloc.xml',
 'index_sort.xml',
 'to_string.xml',
-'set_union.xml'
+'set_union.xml',
+'sparse_rc.xml',
+'sparse_rcv.xml'
 ];
 var list_down0 = [
 'to_string.cpp.xml'
