@@ -1,6 +1,6 @@
-// $Id: get_started.cpp 3757 2015-11-30 12:03:07Z bradbell $
+// $Id: get_started.cpp 3788 2016-02-09 15:50:06Z bradbell $
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-16 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the
@@ -43,7 +43,7 @@ This example will be compiled and tested provided that
 $cref ipopt_prefix$$ is specified on the $cref cmake$$ command line.
 
 $code
-$verbatim%example/ipopt_solve/get_started.cpp%0%// BEGIN C++%// END C++%1%$$
+$srcfile%example/ipopt_solve/get_started.cpp%0%// BEGIN C++%// END C++%1%$$
 $$
 
 $end
