@@ -1,6 +1,6 @@
-// $Id: speed_program.cpp 3757 2015-11-30 12:03:07Z bradbell $
+// $Id: speed_program.cpp 3788 2016-02-09 15:50:06Z bradbell $
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-16 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the
@@ -40,7 +40,7 @@ $codep
 $$
 
 $head Program$$
-$codep */
+$srccode%cpp% */
 # include <cppad/utility/speed_test.hpp>
 
 std::string Test(size_t size, size_t repeat)
@@ -76,7 +76,7 @@ int main(void)
 	return 0;
 }
 
-/* $$
+/* %$$
 
 $head Output$$
 Executing of the program above generated the following output
