@@ -1,6 +1,6 @@
-// $Id: sparse_hessian.cpp 3757 2015-11-30 12:03:07Z bradbell $
+// $Id: sparse_hessian.cpp 3788 2016-02-09 15:50:06Z bradbell $
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-16 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the
@@ -24,7 +24,7 @@ $$
 
 $section Sacado Speed: Sparse Hessian$$
 
-$codep */
+$srccode%cpp% */
 // A sacado version of this test is not yet implemented
 extern bool link_sparse_hessian(
         size_t                           size       ,
@@ -38,6 +38,6 @@ extern bool link_sparse_hessian(
 {
 	return false;
 }
-/* $$
+/* %$$
 $end
 */
