@@ -1,6 +1,6 @@
-// $Id: link_det_lu.cpp 3757 2015-11-30 12:03:07Z bradbell $
+// $Id: link_det_lu.cpp 3855 2016-12-19 00:30:54Z bradbell $
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-16 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the
@@ -110,7 +110,11 @@ bool correct_det_lu(bool is_package_double)
 	return ok;
 }
 void speed_det_lu(size_t size, size_t repeat)
-{	CppAD::vector<double> matrix(size * size);
+{	// free statically allocated memory
+	if( size == 0 && repeat == 0 )
+		return;
+	//
+	CppAD::vector<double> matrix(size * size);
 	CppAD::vector<double> gradient(size * size);
 
 	link_det_lu(size, repeat, matrix, gradient);
